@@ -1,16 +1,18 @@
 # coding: utf-8
+from __future__ import unicode_literals
+from . import columns
+from .config import RequestConfig
+from .rows import BoundRows
+from .utils import (Accessor, AttributeDict, build_request, cached_property,
+                    computed_values, OrderBy, OrderByTuple, segment, Sequence)
 import copy
 from django.core.paginator       import Paginator
 from django.db.models.fields     import FieldDoesNotExist
 from django.utils.datastructures import SortedDict
 from django.template             import RequestContext
 from django.template.loader      import get_template
-from django.utils.encoding       import StrAndUnicode
+import six
 import warnings
-from .utils import (Accessor, AttributeDict, cached_property, build_request,
-                    OrderBy, OrderByTuple, segment, Sequence)
-from .rows  import BoundRows
-from .      import columns
 
 
 QUERYSET_ACCESSOR_SEPARATOR = '__'
@@ -69,7 +71,7 @@ class TableData(object):
             for bound_column in self.table.columns:
                 aliases[bound_column.order_by_alias] = bound_column.order_by
             try:
-                return segment(self.queryset.query.order_by, aliases).next()
+                return next(segment(self.queryset.query.order_by, aliases))
             except StopIteration:
                 pass
 
@@ -97,7 +99,7 @@ class TableData(object):
             translate = lambda accessor: accessor.replace(Accessor.SEPARATOR, QUERYSET_ACCESSOR_SEPARATOR)
             self.queryset = self.queryset.order_by(*(translate(a) for a in accessors))
         else:
-            self.list.sort(cmp=OrderByTuple(accessors).cmp)
+            self.list.sort(key=OrderByTuple(accessors).key)
 
     def __iter__(self):
         """
@@ -146,11 +148,16 @@ class DeclarativeColumnsMetaclass(type):
     ``base_columns`` as well.
     """
     def __new__(mcs, name, bases, attrs):
-
         attrs["_meta"] = opts = TableOptions(attrs.get("Meta", None))
         # extract declared columns
-        cols = [(name_, attrs.pop(name_)) for name_, column in attrs.items()
-                                          if isinstance(column, columns.Column)]
+        cols, remainder = [], {}
+        for attr_name, attr in attrs.items():
+            if isinstance(attr, columns.Column):
+                cols.append((attr_name, attr))
+            else:
+                remainder[attr_name] = attr
+        attrs = remainder
+
         cols.sort(key=lambda x: x[1].creation_counter)
 
         # If this class is subclassing other tables, add their fields as
@@ -159,7 +166,7 @@ class DeclarativeColumnsMetaclass(type):
         parent_columns = []
         for base in bases[::-1]:
             if hasattr(base, "base_columns"):
-                parent_columns = base.base_columns.items() + parent_columns
+                parent_columns = list(base.base_columns.items()) + parent_columns
         # Start with the parent columns
         attrs["base_columns"] = SortedDict(parent_columns)
         # Possibly add some generated columns based on a model
@@ -169,13 +176,14 @@ class DeclarativeColumnsMetaclass(type):
             if opts.fields:
                 # Each item in opts.fields is the name of a model field or a
                 # normal attribute on the model
-                for name in opts.fields:
+                for field_name in opts.fields:
                     try:
-                        field = opts.model._meta.get_field(name)
+                        field = opts.model._meta.get_field(field_name)
                     except FieldDoesNotExist:
-                        extra[name] = columns.Column()
+                        extra[field_name] = columns.Column()
                     else:
-                        extra[name] = columns.library.column_for_field(field)
+                        extra[field_name] = columns.library.column_for_field(field)
+
             else:
                 for field in opts.model._meta.fields:
                     extra[field.name] = columns.library.column_for_field(field)
@@ -193,6 +201,19 @@ class DeclarativeColumnsMetaclass(type):
             # Table's sequence defaults to sequence declared in Meta
             #attrs['_sequence'] = opts.sequence
             attrs["base_columns"] = SortedDict(((x, attrs["base_columns"][x]) for x in opts.sequence))
+
+        # set localize on columns
+        for col_name in attrs["base_columns"].keys():
+            localize_column = None
+            if col_name in opts.localize:
+                localize_column = True
+            # unlocalize gets higher precedence
+            if col_name in opts.unlocalize:
+                localize_column = False
+
+            if localize_column is not None:
+                attrs["base_columns"][col_name].localize = localize_column
+
         return super(DeclarativeColumnsMetaclass, mcs).__new__(mcs, name, bases, attrs)
 
 
@@ -209,12 +230,12 @@ class TableOptions(object):
     def __init__(self, options=None):
         super(TableOptions, self).__init__()
         self.attrs = AttributeDict(getattr(options, "attrs", {}))
-        self.default = getattr(options, "default", u"—")
+        self.default = getattr(options, "default", "—")
         self.empty_text = getattr(options, "empty_text", None)
         self.fields = getattr(options, "fields", ())
         self.exclude = getattr(options, "exclude", ())
         order_by = getattr(options, "order_by", None)
-        if isinstance(order_by, basestring):
+        if isinstance(order_by, six.string_types):
             order_by = (order_by, )
         self.order_by = OrderByTuple(order_by) if order_by is not None else None
         self.order_by_field = getattr(options, "order_by_field", "sort")
@@ -229,9 +250,11 @@ class TableOptions(object):
         self.orderable = self.sortable = getattr(options, "orderable", getattr(options, "sortable", True))
         self.model = getattr(options, "model", None)
         self.template = getattr(options, "template", "django_tables2/table.html")
+        self.localize = getattr(options, "localize", ())
+        self.unlocalize = getattr(options, "unlocalize", ())
 
 
-class Table(StrAndUnicode):
+class TableBase(object):
     """
     A representation of a table.
 
@@ -353,14 +376,13 @@ class Table(StrAndUnicode):
         :type: `unicode`
 
     """
-    __metaclass__ = DeclarativeColumnsMetaclass
     TableDataClass = TableData
 
     def __init__(self, data, order_by=None, orderable=None, empty_text=None,
                  exclude=None, attrs=None, sequence=None, prefix=None,
                  order_by_field=None, page_field=None, per_page_field=None,
-                 template=None, sortable=None, default=None):
-        super(Table, self).__init__()
+                 template=None, sortable=None, default=None, request=None):
+        super(TableBase, self).__init__()
         self.exclude = exclude or ()
         self.sequence = sequence
         self.data = self.TableDataClass(data=data, table=self)
@@ -368,8 +390,9 @@ class Table(StrAndUnicode):
             default = self._meta.default
         self.default = default
         self.rows = BoundRows(data=self.data, table=self)
-        self.attrs = attrs
-        self.empty_text = empty_text
+        self.attrs = AttributeDict(computed_values(attrs if attrs is not None
+                                                         else self._meta.attrs))
+        self.empty_text = empty_text if empty_text is not None else self._meta.empty_text
         if sortable is not None:
             warnings.warn("`sortable` is deprecated, use `orderable` instead.",
                           DeprecationWarning)
@@ -414,9 +437,9 @@ class Table(StrAndUnicode):
         else:
             self.order_by = order_by
         self.template = template
-
-    def __unicode__(self):
-        return unicode(repr(self))
+        # If a request is passed, configure for request
+        if request:
+            RequestConfig(request).configure(self)
 
     def as_html(self):
         """
@@ -432,7 +455,7 @@ class Table(StrAndUnicode):
 
     @property
     def attrs(self):
-        return self._attrs if self._attrs is not None else self._meta.attrs
+        return self._attrs
 
     @attrs.setter
     def attrs(self, value):
@@ -440,8 +463,7 @@ class Table(StrAndUnicode):
 
     @property
     def empty_text(self):
-        return (self._empty_text if self._empty_text is not None
-                                 else self._meta.empty_text)
+        return self._empty_text
 
     @empty_text.setter
     def empty_text(self, value):
@@ -461,7 +483,7 @@ class Table(StrAndUnicode):
         # collapse empty values to ()
         order_by = () if not value else value
         # accept string
-        order_by = order_by.split(',') if isinstance(order_by, basestring) else order_by
+        order_by = order_by.split(',') if isinstance(order_by, six.string_types) else order_by
         valid = []
         # everything's been converted to a iterable, accept iterable!
         for alias in order_by:
@@ -531,15 +553,15 @@ class Table(StrAndUnicode):
 
     @property
     def prefixed_order_by_field(self):
-        return u"%s%s" % (self.prefix, self.order_by_field)
+        return "%s%s" % (self.prefix, self.order_by_field)
 
     @property
     def prefixed_page_field(self):
-        return u"%s%s" % (self.prefix, self.page_field)
+        return "%s%s" % (self.prefix, self.page_field)
 
     @property
     def prefixed_per_page_field(self):
-        return u"%s%s" % (self.prefix, self.per_page_field)
+        return "%s%s" % (self.prefix, self.per_page_field)
 
     @property
     def sequence(self):
@@ -581,3 +603,6 @@ class Table(StrAndUnicode):
     @template.setter
     def template(self, value):
         self._template = value
+
+# Python 2/3 compatible way to enable the metaclass
+Table = DeclarativeColumnsMetaclass(str('Table'), (TableBase, ), {})
