@@ -1,4 +1,5 @@
 from django.conf import global_settings
+import six
 
 
 DATABASES = {
@@ -11,7 +12,6 @@ DATABASES = {
 INSTALLED_APPS = [
     'tests.app',
     'django_tables2',
-    'haystack',
 ]
 
 ROOT_URLCONF = 'tests.app.urls'
@@ -22,9 +22,16 @@ TEMPLATE_CONTEXT_PROCESSORS = [
     'django.core.context_processors.request'
 ] + list(global_settings.TEMPLATE_CONTEXT_PROCESSORS)
 
-HAYSTACK_SEARCH_ENGINE = 'simple',
-HAYSTACK_SITECONF = 'tests.app.models'
-
 TIME_ZONE = "Australia/Brisbane"
 
 USE_TZ = True
+
+if not six.PY3:  # Haystack isn't compatible with Python 3
+    INSTALLED_APPS += [
+        'haystack',
+    ]
+    HAYSTACK_CONNECTIONS = {
+        'default': {
+            'ENGINE': 'haystack.backends.simple_backend.SimpleEngine',
+        }
+    }
\ No newline at end of file
