@@ -80,7 +80,7 @@ def span_attrs():
         col = tables.BooleanColumn(attrs={"span": {"key": "value"}})
 
     table = Table([{"col": True}])
-    assert table.rows[0]["col"] == '<span class="true" key="value">✔</span>'
+    assert attrs(table.rows[0]["col"]) == {"class": "true", "key": "value"}
 
 
 checkboxcolumn = Tests()
@@ -451,11 +451,11 @@ def unicode():
     # test unicode values + headings
     class UnicodeTable(tables.Table):
         first_name = tables.LinkColumn('person', args=[A('pk')])
-        last_name = tables.LinkColumn('person', args=[A('pk')], verbose_name=u'äÚ¨´ˆÁ˜¨ˆ˜˘Ú…Ò˚ˆπ∆ˆ´')
+        last_name = tables.LinkColumn('person', args=[A('pk')], verbose_name='äÚ¨´ˆÁ˜¨ˆ˜˘Ú…Ò˚ˆπ∆ˆ´')
 
     dataset = [
-        {'pk': 1, 'first_name': u'Brädley', 'last_name': u'∆yers'},
-        {'pk': 2, 'first_name': u'Chr…s', 'last_name': u'DÒble'},
+        {'pk': 1, 'first_name': 'Brädley', 'last_name': '∆yers'},
+        {'pk': 2, 'first_name': 'Chr…s', 'last_name': 'DÒble'},
     ]
 
     table = UnicodeTable(dataset)
@@ -463,10 +463,10 @@ def unicode():
     template = Template('{% load django_tables2 %}{% render_table table %}')
     html = template.render(Context({'request': request, 'table': table}))
 
-    assert u'Brädley' in html
-    assert u'∆yers' in html
-    assert u'Chr…s' in html
-    assert u'DÒble' in html
+    assert 'Brädley' in html
+    assert '∆yers' in html
+    assert 'Chr…s' in html
+    assert 'DÒble' in html
 
 
 @linkcolumn.test
@@ -488,8 +488,8 @@ def kwargs():
         a = tables.LinkColumn('occupation', kwargs={"pk": A('a')})
 
     html = PersonTable([{"a": 0}, {"a": 1}]).as_html()
-    assert reverse("occupation", kwargs={b"pk": 0}) in html
-    assert reverse("occupation", kwargs={b"pk": 1}) in html
+    assert reverse("occupation", kwargs={"pk": 0}) in html
+    assert reverse("occupation", kwargs={"pk": 1}) in html
 
 
 @linkcolumn.test
@@ -509,7 +509,7 @@ def old_style_attrs_should_still_work():
                                     attrs={"title": "Occupation Title"})
 
     table = TestTable([{"col": 0}])
-    assert attrs(table.rows[0]["col"]) == {"href": reverse("occupation", kwargs={b"pk": 0}),
+    assert attrs(table.rows[0]["col"]) == {"href": reverse("occupation", kwargs={"pk": 0}),
                                            "title": "Occupation Title"}
 
 
@@ -520,7 +520,7 @@ def a_attrs_should_be_supported():
                                 attrs={"a": {"title": "Occupation Title"}})
 
     table = TestTable([{"col": 0}])
-    assert attrs(table.rows[0]["col"]) == {"href": reverse("occupation", kwargs={b"pk": 0}),
+    assert attrs(table.rows[0]["col"]) == {"href": reverse("occupation", kwargs={"pk": 0}),
                                            "title": "Occupation Title"}
 
 
